# stats_probabilitydistribution package

Summary of package:
This package helps to calculate mean, standard deviation, Probability distribution function for Gaussian distribution and Binomial Distribution.
Through the use of this package we can also plot the distribution to visualize these function and data for better understanding.
Also we can Add two functions directly using method calling.

# Files 
1.README.md 
contains the information about the package.

2.Binomialdistribution.py
This module contains the class Binomial inheriting the Distribution class.
Binomial distribution class is for calculating and  visualizing a Binomial distribution.

3.Gaussiandistribution.py
This module contains the class Gaussian inheriting the Distribution class.
Gaussian distribution class for calculating and visualizing a Gaussian distribution.

4.Generaldistribution.py
This module contains the distribution class.
Generic distribution class for calculating and visualizing a probability distribution.

# Prerequisites:
 python3
 matplotlib
 
# Installation
through command line >>pip3 install stats_probabilitydistribution